==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/he.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "תגיות",
    "Update" : "עדכון",
    "Create" : "יצירה",
    "Select tag…" : "בחירת תגית…",
    "Tagged files" : "קבצים שתויגו",
    "Select tags to filter by" : "תגיות נבחרות מסוננות על ידי",
    "No tags found" : "לא נמצאו תגיות",
    "Please select tags to filter by" : "יש לבחור תגיות שיסוננו על ידי",
    "No files found for the selected tags" : "לא אותרו קבצים לתגיות הנבחרות",
    "Added system tag %1$s" : "נוספה תגית מערכת %1$s",
    "Added system tag {systemtag}" : "נוספה תגית מערכת {systemtag}",
    "%1$s added system tag %2$s" : "תגית המערכת %2$s נוספה על ידי %1$s",
    "{actor} added system tag {systemtag}" : "תגית המערכת {systemtag} נוספה על ידי {actor}",
    "Removed system tag %1$s" : "תגית המערכת %1$s הוסרה",
    "Removed system tag {systemtag}" : "תגית המערכת {systemtag} הוסרה",
    "%1$s removed system tag %2$s" : "תגית המערכת %2$s הוסרה על ידי %1$s",
    "{actor} removed system tag {systemtag}" : "תגית המערכת {systemtag} הוסרה על ידי {actor}",
    "You created system tag %1$s" : "יצרת את תגית המערכת %1$s",
    "You created system tag {systemtag}" : "יצרת את תגית המערכת {systemtag}",
    "%1$s created system tag %2$s" : "%1$s יצר/יצרה תגית מערכת %2$s",
    "{actor} created system tag {systemtag}" : "תגית המערכת {systemtag} נוצרה על ידי {actor}",
    "You deleted system tag %1$s" : "מחקת את תגית המערכת %1$s",
    "You deleted system tag {systemtag}" : "מחקת את תגית המערכת {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s מחק/ה תגית מערכת %2$s",
    "{actor} deleted system tag {systemtag}" : "תגית המערכת {systemtag} נמחקה על ידי {actor}",
    "You updated system tag %2$s to %1$s" : "עדכנת את תגית המערכת %2$s לכדי %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "עדכנת את תגית המערכת {oldsystemtag} לכדי {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s עדכן/עדכנה תגית מערכת %3$s ל- %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "תגית המערכת {oldsystemtag} עודכנה לכדי {newsystemtag} על ידי {actor}",
    "You added system tag %2$s to %1$s" : "הוספת את תגית המערכת %2$s אל %1$s",
    "You added system tag {systemtag} to {file}" : "הוספת את תגית המערכת {systemtag} אל {file}",
    "%1$s added system tag %3$s to %2$s" : "תגית המערכת %3$s נוספה אל %2$s על ידי %1$s",
    "{actor} added system tag {systemtag} to {file}" : "תגית המערכת {systemtag} נוספה אל {file} על ידי {actor}",
    "You removed system tag %2$s from %1$s" : "הסרת את תגית המערכת %2$s מעל %1$s",
    "You removed system tag {systemtag} from {file}" : "הסרת את תגית המערכת {systemtag} מעל {file}",
    "%1$s removed system tag %3$s from %2$s" : "תגית המערכת %3$s הוסרה מעל %2$s על ידי %1$s",
    "{actor} removed system tag {systemtag} from {file}" : "תגית המערכת {systemtag} הוסרה מעל {file} על ידי {actor}",
    "%s (restricted)" : "%s (מוגבל)",
    "%s (invisible)" : "%s (נסתר)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>תגיות מערכת</strong> שהשתנו עבור קובץ",
    "Collaborative tags" : "תגיות שיתופיות",
    "Collaborative tagging functionality which shares tags among users." : "תכונת התיוג השיתופי שמשתפת תגיות בין משתמשים.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "תכונת התיוג השיתופי שמשתפת תגיות בין משתמשים. מעולה לעבודת צוות.\n\t(אם בבעלותך התקנה עם מגוון מערכות נפרדות, מוטב להשבית את היישומון הזה כיוון שהתגיות משותפות.)",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "תגיות שיתופיות זמינות לכל המשתמשים. תגיות מוגבלות חשופות למשתמשים אך אין להם אפשרות להקצות אותן. תגיות בלתי נראות הן לשימוש פנימי כיוון שמשתמשים לא יכולים לראות אות להקצות אותן.",
    "Select tag …" : "מחיקת תגית…",
    "Create a new tag" : "יצירת תגית חדשה",
    "Name" : "שם",
    "Public" : "ציבורית",
    "Restricted" : "מוגבלת",
    "Invisible" : "נסתרת",
    "Delete" : "מחיקה",
    "Reset" : "איפוס",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "Create and edit collaborative tags. These tags affect all users." : "יצירה ועריכה של תגיות שיתופיות. תגיות אלו משפיעות על כל המשתמשים."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/he.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "תגיות",
    "Update" : "עדכון",
    "Create" : "יצירה",
    "Select tag…" : "בחירת תגית…",
    "Tagged files" : "קבצים שתויגו",
    "Select tags to filter by" : "תגיות נבחרות מסוננות על ידי",
    "No tags found" : "לא נמצאו תגיות",
    "Please select tags to filter by" : "יש לבחור תגיות שיסוננו על ידי",
    "No files found for the selected tags" : "לא אותרו קבצים לתגיות הנבחרות",
    "Added system tag %1$s" : "נוספה תגית מערכת %1$s",
    "Added system tag {systemtag}" : "נוספה תגית מערכת {systemtag}",
    "%1$s added system tag %2$s" : "תגית המערכת %2$s נוספה על ידי %1$s",
    "{actor} added system tag {systemtag}" : "תגית המערכת {systemtag} נוספה על ידי {actor}",
    "Removed system tag %1$s" : "תגית המערכת %1$s הוסרה",
    "Removed system tag {systemtag}" : "תגית המערכת {systemtag} הוסרה",
    "%1$s removed system tag %2$s" : "תגית המערכת %2$s הוסרה על ידי %1$s",
    "{actor} removed system tag {systemtag}" : "תגית המערכת {systemtag} הוסרה על ידי {actor}",
    "You created system tag %1$s" : "יצרת את תגית המערכת %1$s",
    "You created system tag {systemtag}" : "יצרת את תגית המערכת {systemtag}",
    "%1$s created system tag %2$s" : "%1$s יצר/יצרה תגית מערכת %2$s",
    "{actor} created system tag {systemtag}" : "תגית המערכת {systemtag} נוצרה על ידי {actor}",
    "You deleted system tag %1$s" : "מחקת את תגית המערכת %1$s",
    "You deleted system tag {systemtag}" : "מחקת את תגית המערכת {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s מחק/ה תגית מערכת %2$s",
    "{actor} deleted system tag {systemtag}" : "תגית המערכת {systemtag} נמחקה על ידי {actor}",
    "You updated system tag %2$s to %1$s" : "עדכנת את תגית המערכת %2$s לכדי %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "עדכנת את תגית המערכת {oldsystemtag} לכדי {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s עדכן/עדכנה תגית מערכת %3$s ל- %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "תגית המערכת {oldsystemtag} עודכנה לכדי {newsystemtag} על ידי {actor}",
    "You added system tag %2$s to %1$s" : "הוספת את תגית המערכת %2$s אל %1$s",
    "You added system tag {systemtag} to {file}" : "הוספת את תגית המערכת {systemtag} אל {file}",
    "%1$s added system tag %3$s to %2$s" : "תגית המערכת %3$s נוספה אל %2$s על ידי %1$s",
    "{actor} added system tag {systemtag} to {file}" : "תגית המערכת {systemtag} נוספה אל {file} על ידי {actor}",
    "You removed system tag %2$s from %1$s" : "הסרת את תגית המערכת %2$s מעל %1$s",
    "You removed system tag {systemtag} from {file}" : "הסרת את תגית המערכת {systemtag} מעל {file}",
    "%1$s removed system tag %3$s from %2$s" : "תגית המערכת %3$s הוסרה מעל %2$s על ידי %1$s",
    "{actor} removed system tag {systemtag} from {file}" : "תגית המערכת {systemtag} הוסרה מעל {file} על ידי {actor}",
    "%s (restricted)" : "%s (מוגבל)",
    "%s (invisible)" : "%s (נסתר)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>תגיות מערכת</strong> שהשתנו עבור קובץ",
    "Collaborative tags" : "תגיות שיתופיות",
    "Collaborative tagging functionality which shares tags among users." : "תכונת תיוג שיתופים שמשתפת תגיות בין המשתמשים.",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "תגיות שיתופיות זמינות לכל המשתמשים. תגיות מוגבלות חשופות למשתמשים אך אין להם אפשרות להקצות אותן. תגיות בלתי נראות הן לשימוש פנימי כיוון שמשתמשים לא יכולים לראות אות להקצות אותן.",
    "Select tag …" : "מחיקת תגית…",
    "Create a new tag" : "יצירת תגית חדשה",
    "Name" : "שם",
    "Public" : "ציבורית",
    "Restricted" : "מוגבלת",
    "Invisible" : "נסתרת",
    "Delete" : "מחיקה",
    "Reset" : "איפוס",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "Create and edit collaborative tags. These tags affect all users." : "יצירה ועריכה של תגיות שיתופיות. תגיות אלו משפיעות על כל המשתמשים."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
